@@ -95,7 +95,7 @@ pub enum DefsLookupErrorKind {
     /// Used when the public API tries to look up an external URL, which is not allowed.
     ///
     /// This catches the case where a public API wants to be misused to access an external
-    /// resource.  For example, `SvgHandle.has_sub("https://evil.com/phone_home#element_id") will
+    /// resource.  For example, `SvgHandle.has_sub("https://evil.com/phone_home#element_id")` will
     /// fail with this error.
     CannotLookupExternalReferences,
 
@@ -167,10 +167,30 @@ impl From<cairo::Error> for RenderingError {
     }
 }
 
+/// Errors from [`crate::document::AcquiredNodes`].
 pub enum AcquireError {
+    /// An element with the specified id was not found.
     LinkNotFound(NodeId),
+
     InvalidLinkType(NodeId),
+
+    /// A circular reference was detected; non-fatal error.
+    ///
+    /// Callers are expected to treat the offending element as invalid, for example
+    /// if a graphic element uses a pattern fill, but the pattern in turn includes
+    /// another graphic element that references the same pattern.
+    ///
+    /// ```xml
+    /// <pattern id="foo">
+    ///   <rect width="1" height="1" fill="url(#foo)"/>
+    /// </pattern>
+    /// ```
     CircularReference(Node),
+
+    /// Too many referenced objects were resolved; fatal error.
+    ///
+    /// Callers are expected to exit as early as possible and return an error to
+    /// the public API.  See [`ImplementationLimit::TooManyReferencedElements`] for details.
     MaxReferencesExceeded,
 }
 
@@ -293,12 +313,6 @@ pub enum AllowedUrlError {
     /// or in one directory below the base file.
     NotSiblingOrChildOfBaseFile,
 
-    /// Loaded file:// URLs cannot have a query part, e.g. `file:///foo?blah`
-    NoQueriesAllowed,
-
-    /// URLs may not have fragment identifiers at this stage
-    NoFragmentIdentifierAllowed,
-
     /// Error when obtaining the file path or the base file path
     InvalidPath,
 
@@ -311,18 +325,17 @@ pub enum AllowedUrlError {
 
 impl fmt::Display for AllowedUrlError {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        use AllowedUrlError::*;
         match *self {
-            UrlParseError(e) => write!(f, "URL parse error: {}", e),
-            BaseRequired => write!(f, "base required"),
-            DifferentUriSchemes => write!(f, "different URI schemes"),
-            DisallowedScheme => write!(f, "disallowed scheme"),
-            NotSiblingOrChildOfBaseFile => write!(f, "not sibling or child of base file"),
-            NoQueriesAllowed => write!(f, "no queries allowed"),
-            NoFragmentIdentifierAllowed => write!(f, "no fragment identifier allowed"),
-            InvalidPath => write!(f, "invalid path"),
-            BaseIsRoot => write!(f, "base is root"),
-            CanonicalizationError => write!(f, "canonicalization error"),
+            AllowedUrlError::UrlParseError(e) => write!(f, "URL parse error: {}", e),
+            AllowedUrlError::BaseRequired => write!(f, "base required"),
+            AllowedUrlError::DifferentUriSchemes => write!(f, "different URI schemes"),
+            AllowedUrlError::DisallowedScheme => write!(f, "disallowed scheme"),
+            AllowedUrlError::NotSiblingOrChildOfBaseFile => {
+                write!(f, "not sibling or child of base file")
+            }
+            AllowedUrlError::InvalidPath => write!(f, "invalid path"),
+            AllowedUrlError::BaseIsRoot => write!(f, "base is root"),
+            AllowedUrlError::CanonicalizationError => write!(f, "canonicalization error"),
         }
     }
 }
